@@ -2,7 +2,7 @@ package CPAN::MirrorMerger;
 use strict;
 use warnings;
 
-our $VERSION = "0.04";
+our $VERSION = "0.05";
 
 use Class::Accessor::Lite ro => [qw/mirrors/];
 
@@ -14,7 +14,7 @@ use CPAN::MirrorMerger::Mirror;
 use CPAN::MirrorMerger::MirrorCache;
 use CPAN::MirrorMerger::RetryPolicy;
 use CPAN::MirrorMerger::Logger::Null;
-use CPAN::MirrorMerger::Algorithm::Simple;
+use CPAN::MirrorMerger::Algorithm::PreferLatestVersion;
 
 our $DEFAULT_LOGGER = CPAN::MirrorMerger::Logger::Null->instance();
 our $DEFAULT_RETRY_POLICY = CPAN::MirrorMerger::RetryPolicy->new(
@@ -47,7 +47,7 @@ sub merge {
 }
 
 sub _get_default_algorithm {
-    return CPAN::MirrorMerger::Algorithm::Simple->new(
+    return CPAN::MirrorMerger::Algorithm::PreferLatestVersion->new(
         mirror_cache => _get_default_mirror_cache(),
         logger       => $DEFAULT_LOGGER,
     );
@@ -90,7 +90,7 @@ CPAN::MirrorMerger - CPAN Mirror index merger for many legacy company internal C
     $merger->add_mirror('http://backpan.perl.org/');
     $merger->add_mirror('https://cpan.metacpan.org/');
 
-    $merger->merge()->save(
+    $merger->merge()->save_with_included_packages(
         CPAN::MirrorMerger::Storage::Directory->new(path => '/tmp/merged'),
     );
 
