@@ -7,11 +7,18 @@ use parent qw/CPAN::MirrorMerger::Index/;
 use Class::Accessor::Lite
     ro => [qw/multiplex_index mirrors mirror_cache logger/];
 
-sub save {
+sub save_with_included_packages {
     my ($self, $storage) = @_;
+
     for my $mirror (@{ $self->mirrors }) {
         my $index = $self->mirror_cache->get_or_fetch_index($mirror);
+
+        my $previous_package_path = '';
         for my $package_info (@{ $index->packages }) {
+            # skip contiguous packages for performance
+            next if $previous_package_path eq $package_info->canonicalized_path();
+            $previous_package_path = $package_info->canonicalized_path();
+
             my $package_path = eval {
                 $self->mirror_cache->get_or_fetch_package($mirror, $package_info);
             };
@@ -23,11 +30,12 @@ sub save {
                 $self->logger->error("failed to fetch package @{[ $package_info->path ]} on @{[ $mirror->name ]}");
                 die $e;
             }
+
             my $save_key = $mirror->package_path($package_info->canonicalized_path);
             $storage->copy($package_path, $save_key);
         }
     }
-    $self->SUPER::save($storage);
+    $self->save($storage);
 }
 
 1;
